@@ -6,6 +6,7 @@ from __future__ import unicode_literals
 
 import array
 import calendar
+import datetime
 import io
 import itertools
 import socket
@@ -19,8 +20,7 @@ try:
     from ftplib import FTP_TLS
 except ImportError as err:
     FTP_TLS = err  # type: ignore
-from ftplib import error_perm
-from ftplib import error_temp
+from ftplib import error_perm, error_temp
 from typing import cast
 
 from six import PY2
@@ -40,6 +40,7 @@ from .path import dirname
 from .path import basename
 from .path import normpath
 from .path import split
+from .time import epoch_to_datetime
 from . import _ftp_parse as ftp_parse
 
 if typing.TYPE_CHECKING:
@@ -572,6 +573,12 @@ class FTPFS(FS):
         """bool: whether the server supports MLST feature."""
         return "MLST" in self.features
 
+    @property
+    def supports_mdtm(self):
+        # type: () -> bool
+        """bool: whether the server supports the MDTM feature."""
+        return "MDTM" in self.features
+
     def create(self, path, wipe=False):
         # type: (Text, bool) -> bool
         _path = self.validatepath(path)
@@ -692,8 +699,21 @@ class FTPFS(FS):
         if namespace == "standard":
             _meta = self._meta.copy()
             _meta["unicode_paths"] = "UTF8" in self.features
+            _meta["supports_mtime"] = "MDTM" in self.features
         return _meta
 
+    def getmodified(self, path):
+        # type: (Text) -> Optional[datetime.datetime]
+        if self.supports_mdtm:
+            _path = self.validatepath(path)
+            with self._lock:
+                with ftp_errors(self, path=path):
+                    cmd = "MDTM " + _encode(_path, self.ftp.encoding)
+                    response = self.ftp.sendcmd(cmd)
+                    mtime = self._parse_ftp_time(response.split()[1])
+                    return epoch_to_datetime(mtime)
+        return super(FTPFS, self).getmodified(path)
+
     def listdir(self, path):
         # type: (Text) -> List[Text]
         _path = self.validatepath(path)
@@ -836,8 +856,32 @@ class FTPFS(FS):
 
     def setinfo(self, path, info):
         # type: (Text, RawInfo) -> None
-        if not self.exists(path):
-            raise errors.ResourceNotFound(path)
+        use_mfmt = False
+        if "MFMT" in self.features:
+            info_details = None
+            if "modified" in info:
+                info_details = info["modified"]
+            elif "details" in info:
+                info_details = info["details"]
+            if info_details and "modified" in info_details:
+                use_mfmt = True
+                mtime = cast(float, info_details["modified"])
+
+        if use_mfmt:
+            with ftp_errors(self, path):
+                cmd = (
+                    "MFMT "
+                    + datetime.datetime.utcfromtimestamp(mtime).strftime("%Y%m%d%H%M%S")
+                    + " "
+                    + _encode(path, self.ftp.encoding)
+                )
+                try:
+                    self.ftp.sendcmd(cmd)
+                except error_perm:
+                    pass
+        else:
+            if not self.exists(path):
+                raise errors.ResourceNotFound(path)
 
     def readbytes(self, path):
         # type: (Text) -> bytes
